/*
 * Copyright 2014 Canonical Ltd.
 *
 * This file is part of ubuntu-html5-container.
 *
 * ubuntu-html5-container is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * webbrowser-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1


/*!
    \qmltype WebAppContainer
    \inqmlmodule Ubuntu.WebApps 0.1
    \ingroup ubuntu
    \brief WebAppContainer is the root element that should be used for all HTML5 applications.
*/
MainView {
    id: root
    objectName: "root"

    anchorToKeyboard: true
    automaticOrientation: true

    /*!
      \preliminary
      The property defines if oxide is to be used as the webengine backend.
      */
    property bool oxide: true

    /*!
      \preliminary
      The property holds the path to the filesystem location where the 'index.html'
      file can be found (root of the HTML5 application).

      The path is absolute or relative to the current dir.
      */
    property string htmlIndexDirectory: ""

    /*!
      \preliminary
      The properties hold whether the remote debugging interface should be enabled for the
      Web View. The host ip and port for accessing the remote interface should be provided.
      */
    property bool remoteInspectorEnabled: false

    Page {
        id: mainPage
        anchors.fill: parent

        /*!
          \internal
         */
        function _getAppStartupIndexFileUri() {
            return 'file://' + root.htmlIndexDirectory + '/index.html';
        }

        /*!
          \internal
         */
        Loader {
            id: webviewComponentLoader
            anchors.fill: parent
            onLoaded: {
                bindings.bindingMainWebview = item;
            }
        }

        Component.onCompleted: {
            var webview = oxide ?
                Qt.resolvedUrl("WebViewOxide.qml")
                : Qt.resolvedUrl("WebViewWebkit.qml");
            webviewComponentLoader.setSource(webview, {
                remoteInspectorEnabled: root.remoteInspectorEnabled});
        }

        /*!
          \internal
         */
        UbuntuJavascriptBindings {
            id: bindings
            onReady: {
                webviewComponentLoader.item.url =
                    mainPage._getAppStartupIndexFileUri();
            }
        }
    }
}

